@@ -7,10 +7,10 @@
 #define BOINC_MAJOR_VERSION 7
 
 /* Minor part of BOINC version number */
-#define BOINC_MINOR_VERSION 10
+#define BOINC_MINOR_VERSION 12
 
 /* Release part of BOINC version number */
-#define BOINC_RELEASE 3
+#define BOINC_RELEASE 1
 
 /* Release part of wrapper version number */
 #define WRAPPER_RELEASE 26016
@@ -19,10 +19,10 @@
 #define VBOXWRAPPER_RELEASE 26200
 
 /* String representation of BOINC version number */
-#define BOINC_VERSION_STRING "7.10.3"
+#define BOINC_VERSION_STRING "7.12.1"
 
 /* Package is a pre-release (Alpha/Beta) package */
-#define BOINC_PRERELEASE 1
+//#define BOINC_PRERELEASE 1
 
 #if (defined(_WIN32) || defined(__APPLE__))
 /* Name of package */
@@ -35,13 +35,13 @@
 #define PACKAGE_NAME "BOINC"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "BOINC 7.10.3"
+#define PACKAGE_STRING "BOINC 7.12.1"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "boinc"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "7.10.3"
+#define PACKAGE_VERSION "7.12.1"
 
 #endif /* #if (defined(_WIN32) || defined(__APPLE__)) */
 
